@@ -25,7 +25,7 @@
 package EBook::EPUB;
 
 use version;
-our $VERSION = 0.5;
+our $VERSION = 0.6;
 
 use Moose;
 
@@ -50,12 +50,14 @@ has metadata    => (
     default => sub { EBook::EPUB::Metadata->new() },
     handles => [ qw/add_contributor
                     add_creator
+                    add_coverage
                     add_date
                     add_meta_dcitem
                     add_description
                     add_format
                     add_meta_item
                     add_language
+                    add_publisher
                     add_relation
                     add_rights
                     add_source
@@ -129,9 +131,8 @@ sub BUILD
     mkdir ($self->tmpdir . "/OPS") or die "Can't make OPS dir in " . $self->tmpdir;
     # Implicitly generate UUID for book
     my $ug = new Data::UUID;
-    my $uuid = $ug->create_from_name_str(NameSpace_URL, "EBook::EPUB");
+    my $uuid = $ug->create_str();
     $self->_set_uuid($uuid);
-
 }
 
 sub to_xml
@@ -145,7 +146,7 @@ sub to_xml
         DATA_INDENT => 2,
     );
 
-    $writer->xmlDecl();
+    $writer->xmlDecl("utf-8");
     $writer->startTag('package', 
         xmlns               => 'http://www.idpf.org/2007/opf',
         version             => '2.0',
@@ -464,7 +465,7 @@ sub pack_zip
     foreach my $fref ($self->encrypted_filerefs) {
         $container->add_encrypted_path($fref);
     }
-    $container->write();
+    return $container->write();
 }
 
 sub write_opf
@@ -543,7 +544,7 @@ EBook::EPUB - module for generating EPUB documents
 
 =head1 VERSION
 
-Version 0.5
+Version 0.6
 
 
 =head1 SYNOPSIS
@@ -621,6 +622,9 @@ suitable for machine processing, e.g.  "Doyle, Arthur Conan". $role reflects
 kind of contribution to document. See Section 2.2.6 of OPF specification for
 list of possible values L<http://www.idpf.org/2007/opf/OPF_2.0_final_spec.html#Section2.2.6>
 
+=item add_coverage($coverage)
+
+The extent or scope of the content of the resource.
 
 =item add_date($date, [$event])
 
@@ -645,6 +649,10 @@ The media type or dimensions of the resource. Best practice is to use a value fr
 Add language of the content of the publication. $lang must comply with RFC 3066
 (see http://www.ietf.org/rfc/rfc3066.txt)
 
+=item add_publisher($publisher)
+
+An entity responsible for making the resource available
+
 =item add_relation($relation)
 
 An identifier of an auxiliary resource and its relationship to the publication.
